@@ -1,24 +1,24 @@
+( cd opt/kde/lib ; rm -rf libsmokekde.so.1 )
+( cd opt/kde/lib ; ln -sf libsmokekde.so.1.2.2 libsmokekde.so.1 )
+( cd opt/kde/lib ; rm -rf libsmokekde.so )
+( cd opt/kde/lib ; ln -sf libsmokekde.so.1.2.2 libsmokekde.so )
 ( cd opt/kde/lib ; rm -rf libqtjava.so )
 ( cd opt/kde/lib ; ln -sf libqtjava.so.1.0.0 libqtjava.so )
-( cd opt/kde/lib ; rm -rf libqtc.so.1 )
-( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so.1 )
-( cd opt/kde/lib ; rm -rf libqtc.so )
-( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so )
-( cd opt/kde/lib ; rm -rf libkdec.so.1 )
-( cd opt/kde/lib ; ln -sf libkdec.so.1.2.0 libkdec.so.1 )
 ( cd opt/kde/lib ; rm -rf libkjsembed.so )
 ( cd opt/kde/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so )
 ( cd opt/kde/lib ; rm -rf libsmokeqt.so.1 )
-( cd opt/kde/lib ; ln -sf libsmokeqt.so.1.2.1 libsmokeqt.so.1 )
+( cd opt/kde/lib ; ln -sf libsmokeqt.so.1.2.2 libsmokeqt.so.1 )
 ( cd opt/kde/lib ; rm -rf libkjsembed.so.1 )
 ( cd opt/kde/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so.1 )
 ( cd opt/kde/lib ; rm -rf libkdejava.so.1 )
 ( cd opt/kde/lib ; ln -sf libkdejava.so.1.0.0 libkdejava.so.1 )
 ( cd opt/kde/lib ; rm -rf libkdejava.so )
 ( cd opt/kde/lib ; ln -sf libkdejava.so.1.0.0 libkdejava.so )
-( cd opt/kde/lib ; rm -rf libkdec.so )
-( cd opt/kde/lib ; ln -sf libkdec.so.1.2.0 libkdec.so )
+( cd opt/kde/lib ; rm -rf libqtjavasupport.so )
+( cd opt/kde/lib ; ln -sf libqtjavasupport.so.1.0.0 libqtjavasupport.so )
 ( cd opt/kde/lib ; rm -rf libqtjava.so.1 )
 ( cd opt/kde/lib ; ln -sf libqtjava.so.1.0.0 libqtjava.so.1 )
+( cd opt/kde/lib ; rm -rf libqtjavasupport.so.1 )
+( cd opt/kde/lib ; ln -sf libqtjavasupport.so.1.0.0 libqtjavasupport.so.1 )
 ( cd opt/kde/lib ; rm -rf libsmokeqt.so )
-( cd opt/kde/lib ; ln -sf libsmokeqt.so.1.2.1 libsmokeqt.so )
+( cd opt/kde/lib ; ln -sf libsmokeqt.so.1.2.2 libsmokeqt.so )
